@@ -1,5 +1,6 @@
 from django.http import HttpResponse, HttpResponseBadRequest
 from django.views.decorators.csrf import csrf_exempt
+from django.contrib.auth.decorators import login_required
 from django.contrib import messages
 from django.core.files.uploadedfile import UploadedFile
 from django.conf import settings
@@ -16,6 +17,7 @@ except ImportError:
 
 HANDLERS = dict(getattr(settings, 'FILEUPLOAD_HANDLERS', DEFAULT_HANDLERS))
 
+@login_required
 @csrf_exempt
 def upload(request):
     handler = request.GET.get('handler')
@@ -110,11 +112,17 @@ def upload(request):
             fail += 1
             continue
 
-    return HttpResponse(
-        simplejson.dumps(result),
-        content_type = 'application/json'
+    if success:
+        return HttpResponse(
+            simplejson.dumps(result),
+            content_type = 'application/json'
+        )
+
+    return HttpResponseBadRequest(
+        'Your files could not be uploaded.'
     )
 
+@login_required
 @csrf_exempt
 def delete(request):
     handler = request.GET.get('handler')
@@ -176,6 +184,7 @@ def delete(request):
         content_type = 'application/json'
     )
 
+@login_required
 def filelist(request):
     handler = request.GET.get('handler')
     logger = getLogger('bambu_fileupload')
